@@ -27,7 +27,7 @@ has dbi => (
 );
 
 # 配置解析器
-has parser => ( is => 'ro', does => 'Firewall::Config::Parser::Role', required => 1, );
+has parser => (is => 'ro', does => 'Firewall::Config::Parser::Role', required => 1,);
 
 #------------------------------------------------------------------------------
 # fwId 获取防火墙 id
@@ -65,25 +65,25 @@ sub saveZone {
   my $tableName = 'fw_zone_state';
 
   # 初始化数据结构
-  my ( $newZones, $oldZones );
+  my ($newZones, $oldZones);
   my $zoneExistsStatus = {new => {}, old => {}};
 
   # 遍历快照中的网络区域,写入 newZones 和 zoneExistsStatus
-  for my $zoneObj ( values $self->{parser}{elements}{zone}->%* ) {
+  for my $zoneObj (values $self->{parser}{elements}{zone}->%*) {
     my $zoneName = $zoneObj->{name};
     $newZones->{$zoneName} = undef;
     $zoneExistsStatus->{new}{$zoneName} = undef;
   }
 
   # 查询已有网络区域数据,写入 oldZones
-  $oldZones = $self->select( column => ['zone'], table => $tableName, where => {fw_id => $self->{parser}{fwId}} )->all;
+  $oldZones = $self->select(column => ['zone'], table => $tableName, where => {fw_id => $self->{parser}{fwId}})->all;
 
   # 寻找差量数据
-  for my $zoneName ( map { $_->{zone} } $oldZones->@* ) {
+  for my $zoneName (map { $_->{zone} } $oldZones->@*) {
 
     # 新旧zones均存在,则不是新的数据
-    if ( exists $newZones->{$zoneName} ) {
-      delete( $zoneExistsStatus->{new}{$zoneName} );
+    if (exists $newZones->{$zoneName}) {
+      delete($zoneExistsStatus->{new}{$zoneName});
     }
     else {
       $zoneExistsStatus->{old}{$zoneName} = undef;
@@ -91,17 +91,17 @@ sub saveZone {
   }
 
   # 根据网络区域状态更新数据
-  if ( keys $zoneExistsStatus->{new}->%* > 0 ) {
+  if (keys $zoneExistsStatus->{new}->%* > 0) {
     my $sql    = "insert into $tableName (fw_id, zone) values (?, ?)";
-    my $params = [ map { [ $self->fwId, $_ ] } keys $zoneExistsStatus->{new}->%* ];
-    $self->batchExecute( $params, $sql );
+    my $params = [map { [$self->fwId, $_] } keys $zoneExistsStatus->{new}->%*];
+    $self->batchExecute($params, $sql);
   }
 
   # 设置 state 为 0 代表停用状态
-  if ( keys $zoneExistsStatus->{old}->%* > 0 ) {
+  if (keys $zoneExistsStatus->{old}->%* > 0) {
     my $sql    = "update $tableName set state = 1 where fw_id = ? and zone = ?";
-    my $params = [ map { [ $self->fwId, $_ ] } keys $zoneExistsStatus->{old}->%* ];
-    $self->batchExecute( $params, $sql );
+    my $params = [map { [$self->fwId, $_] } keys $zoneExistsStatus->{old}->%*];
+    $self->batchExecute($params, $sql);
   }
 }
 
@@ -112,15 +112,14 @@ sub saveInterface {
   my $self = shift;
 
   # 定义 SQL 语句
-  my $sql
-    = "insert into fw_interface (fw_id,interface_name,ipaddress,interface_range,zonename,config,type) values(?,?,?,?,?,?,?)
+  my $sql = "insert into fw_interface (fw_id,interface_name,ipaddress,interface_range,zonename,config,type) values(?,?,?,?,?,?,?)
     ON CONFLICT(fw_id,interface_name) do update set config=EXCLUDED.config,interface_range = EXCLUDED.interface_range,ipaddress=EXCLUDED.ipaddress";
 
   # 初始化变量
   my $params;
 
   # 编辑快照解析到的接口对象
-  for my $interface ( values $self->{parser}{elements}{interface}->%* ) {
+  for my $interface (values $self->{parser}{elements}{interface}->%*) {
 
     # 构造 SQL VALUES
     my @ints;
@@ -132,7 +131,7 @@ sub saveInterface {
     push @ints, $interface->{name};
 
     # ipaddress
-    if ( defined $interface->{ipAddress} ) {
+    if (defined $interface->{ipAddress}) {
       push @ints, $interface->{ipAddress} . "/" . $interface->{mask};
     }
     else {
@@ -154,7 +153,7 @@ sub saveInterface {
     # 将数据压入 $params
     push $params->@*, \@ints;
   }
-  $self->batchExecute( $params, $sql );
+  $self->batchExecute($params, $sql);
 }
 
 #------------------------------------------------------------------------------
@@ -164,7 +163,7 @@ sub saveNat {
   my $self = shift;
 
   # 保存之前删除历史数据
-  $self->delete( where => {fw_id => $self->{parser}{fwId}}, table => "fw_nat_table" );
+  $self->delete(where => {fw_id => $self->{parser}{fwId}}, table => "fw_nat_table");
 
   # 定义 sql 插入语句
   my $sql
@@ -175,7 +174,7 @@ sub saveNat {
   my $params;
 
   # 查询防火墙快照中的静态地址转换
-  for my $staticNat ( values $self->{parser}{elements}{staticNat}->%* ) {
+  for my $staticNat (values $self->{parser}{elements}{staticNat}->%*) {
 
     # 构造 SQL VALUES
     my @nat;
@@ -222,7 +221,7 @@ sub saveNat {
     push $params->@*, \@nat;
   }
 
-  for my $dyNat ( values $self->{parser}{elements}{dynamicNat}->%* ) {
+  for my $dyNat (values $self->{parser}{elements}{dynamicNat}->%*) {
 
     # 构造 SQL VALUES
     my @nat;
@@ -235,21 +234,15 @@ sub saveNat {
 
     # src_range | 动态地址转换包括源地址和目的地址两个方向，该值可能不存在
     push @nat,
-      defined $dyNat->{srcIpRange}
-      ? encode_json {mins => $dyNat->{srcIpRange}{mins}, maxs => $dyNat->{srcIpRange}{maxs}}
-      : undef;
+      defined $dyNat->{srcIpRange} ? encode_json {mins => $dyNat->{srcIpRange}{mins}, maxs => $dyNat->{srcIpRange}{maxs}} : undef;
 
     # dst_range | 动态地址转换包括源地址和目的地址两个方向，该值可能不存在
     push @nat,
-      defined $dyNat->{dstIpRange}
-      ? encode_json {mins => $dyNat->{dstIpRange}{mins}, maxs => $dyNat->{dstIpRange}{maxs}}
-      : undef;
+      defined $dyNat->{dstIpRange} ? encode_json {mins => $dyNat->{dstIpRange}{mins}, maxs => $dyNat->{dstIpRange}{maxs}} : undef;
 
     # srv_range | 动态地址转换包括源地址和目的地址两个方向，该值可能不存在
     push @nat,
-      defined $dyNat->srvRange
-      ? encode_json {mins => $dyNat->{srvRange}{mins}, maxs => $dyNat->{srvRange}{maxs}}
-      : undef;
+      defined $dyNat->srvRange ? encode_json {mins => $dyNat->{srvRange}{mins}, maxs => $dyNat->{srvRange}{maxs}} : undef;
 
     # nat_src_range | 动态地址转换包括源地址和目的地址两个方向，该值可能不存在
     push @nat,
@@ -290,7 +283,7 @@ sub saveNat {
     # 将数据压入 params
     push $params->@*, \@nat;
   }
-  $self->batchExecute( $params, $sql );
+  $self->batchExecute($params, $sql);
 }
 
 #------------------------------------------------------------------------------
@@ -300,7 +293,7 @@ sub saveRule {
   my $self = shift;
 
   # 插入数据之前删除历史数据
-  $self->delete( where => {fw_id => $self->fwId}, table => "fw_rule" );
+  $self->delete(where => {fw_id => $self->fwId}, table => "fw_rule");
 
   # 定义 SQL 语句
   my $sql
@@ -310,7 +303,7 @@ sub saveRule {
   my $params;
 
   # 遍历解析到的防火墙策略
-  for my $rule ( values $self->{parser}{elements}{rule}->%* ) {
+  for my $rule (values $self->{parser}{elements}{rule}->%*) {
 
     # 构造 SQL VALUES
     my @rules;
@@ -347,7 +340,7 @@ sub saveRule {
     push @rules, $rule->{action};
 
     # rule_state
-    if ( $rule->{isDisable} eq 'enable' ) {
+    if ($rule->{isDisable} eq 'enable') {
       push @rules, 1;
     }
     else {
@@ -355,7 +348,7 @@ sub saveRule {
     }
 
     # expire_date
-    if ( defined $rule->{schedule} and $rule->{schedule}->schType eq 'onetime' ) {
+    if (defined $rule->{schedule} and $rule->{schedule}->schType eq 'onetime') {
       push @rules, $rule->{schedule}->getEnddateStr;
     }
     else {
@@ -375,7 +368,7 @@ sub saveRule {
     push @rules, $rule->{content};
 
     # other
-    if ( defined $rule->{fromInterface} or defined $rule->{toInterface} ) {
+    if (defined $rule->{fromInterface} or defined $rule->{toInterface}) {
       my %hash;
       $hash{fromInterface} = $rule->{fromInterface} if defined $rule->{fromInterface};
       $hash{toInterface}   = $rule->{toInterface}   if defined $rule->{toInterface};
@@ -390,32 +383,29 @@ sub saveRule {
 
     # src_range
     my @src_range;
-    for ( my $i = 0; $i < $rule->srcAddressGroup->range->mins->@*; $i++ ) {
-      push @src_range,
-        "[" . $rule->srcAddressGroup->range->mins->[$i] . "," . $rule->srcAddressGroup->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < $rule->srcAddressGroup->range->mins->@*; $i++) {
+      push @src_range, "[" . $rule->srcAddressGroup->range->mins->[$i] . "," . $rule->srcAddressGroup->range->maxs->[$i] . "]";
     }
     push @rules, \@src_range;
 
     # dst_range
     my @dst_range;
-    for ( my $i = 0; $i < $rule->dstAddressGroup->range->mins->@*; $i++ ) {
-      push @dst_range,
-        "[" . $rule->dstAddressGroup->range->mins->[$i] . "," . $rule->dstAddressGroup->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < $rule->dstAddressGroup->range->mins->@*; $i++) {
+      push @dst_range, "[" . $rule->dstAddressGroup->range->mins->[$i] . "," . $rule->dstAddressGroup->range->maxs->[$i] . "]";
     }
     push @rules, \@dst_range;
 
     # srv_range
     my @srv_range;
-    for ( my $i = 0; $i < $rule->serviceGroup->range->mins->@*; $i++ ) {
-      push @srv_range,
-        "[" . $rule->serviceGroup->range->mins->[$i] . "," . $rule->serviceGroup->range->maxs->[$i] . "]";
+    for (my $i = 0; $i < $rule->serviceGroup->range->mins->@*; $i++) {
+      push @srv_range, "[" . $rule->serviceGroup->range->mins->[$i] . "," . $rule->serviceGroup->range->maxs->[$i] . "]";
     }
     push @rules, \@srv_range;
 
     # 将数据压入 params
     push $params->@*, \@rules;
   }
-  $self->batchExecute( $params, $sql );
+  $self->batchExecute($params, $sql);
 }
 
 #------------------------------------------------------------------------------
@@ -425,7 +415,7 @@ sub saveRoute {
   my $self = shift;
 
   # 插入数据之前删除历史数据
-  $self->delete( where => {fw_id => $self->fwId}, table => "fw_route" );
+  $self->delete(where => {fw_id => $self->fwId}, table => "fw_route");
 
   # 定义 SQL 语句
   my $sql
@@ -435,7 +425,7 @@ sub saveRoute {
   my $params;
 
   # 遍历解析到的路由条目
-  for my $route ( values $self->{parser}{elements}{route}->%* ) {
+  for my $route (values $self->{parser}{elements}{route}->%*) {
 
     # 构造 SQL VALUES
     my @route;
@@ -471,7 +461,7 @@ sub saveRoute {
     push @route, undef;
 
     # other
-    if ( defined $route->{srcInterface} or defined $route->{srcRange} or defined $route->{routeInstance} ) {
+    if (defined $route->{srcInterface} or defined $route->{srcRange} or defined $route->{routeInstance}) {
       my %hash;
 
       # 路由关联源接口
@@ -490,7 +480,7 @@ sub saveRoute {
 
     # network_set
     my @network_set;
-    for ( my $i = 0; $i < $route->range->mins->@*; $i++ ) {
+    for (my $i = 0; $i < $route->range->mins->@*; $i++) {
       push @network_set, "[" . $route->range->mins->[$i] . "," . $route->range->maxs->[$i] . "]";
     }
     push @route, \@network_set;
@@ -498,7 +488,7 @@ sub saveRoute {
     # 将数据压入 params
     push $params->@*, \@route;
   }
-  $self->batchExecute( $params, $sql );
+  $self->batchExecute($params, $sql);
 }
 
 #------------------------------------------------------------------------------
@@ -508,7 +498,7 @@ sub saveService {
   my $self = shift;
 
   # 插入数据之前删除历史数据
-  $self->delete( where => {fw_id => $self->fwId}, table => "fw_service" );
+  $self->delete(where => {fw_id => $self->fwId}, table => "fw_service");
 
   # 定义 SQL 语句
   my $sql = "insert into fw_service (fw_id,service_name,ref_num,config,service_set,service_range) values(?,?,?,?,?,?)
@@ -518,7 +508,7 @@ sub saveService {
   my $params;
 
   # 遍历解析到的服务端口对象
-  for my $serv ( values $self->{parser}{elements}{service}->%* ) {
+  for my $serv (values $self->{parser}{elements}{service}->%*) {
 
     # 构造 SQL VALUES
     my @serv;
@@ -540,7 +530,7 @@ sub saveService {
 
     # service_range
     my @service_range;
-    for ( my $i = 0; $i < $serv->range->mins->@*; $i++ ) {
+    for (my $i = 0; $i < $serv->range->mins->@*; $i++) {
       push @service_range, "[" . $serv->range->mins->[$i] . "," . $serv->range->maxs->[$i] . "]";
     }
     push @serv, \@service_range;
@@ -548,7 +538,7 @@ sub saveService {
     # 将数据压入 $params
     push $params->@*, \@serv;
   }
-  $self->batchExecute( $params, $sql );
+  $self->batchExecute($params, $sql);
 }
 
 #------------------------------------------------------------------------------
@@ -558,18 +548,17 @@ sub saveAddress {
   my $self = shift;
 
   # 插入数据之前删除历史数据
-  $self->delete( where => {fw_id => $self->fwId}, table => "fw_address" );
+  $self->delete(where => {fw_id => $self->fwId}, table => "fw_address");
 
   # 定义 SQL 语句
-  my $sql
-    = "insert into fw_address (fw_id,addr_name,ref_num,config,address_set,address_range,other) values(?,?,?,?,?,?,?)
+  my $sql = "insert into fw_address (fw_id,addr_name,ref_num,config,address_set,address_range,other) values(?,?,?,?,?,?,?)
     ON CONFLICT(fw_id,addr_name) do update set config=EXCLUDED.config,address_set=EXCLUDED.address_set,address_range=EXCLUDED.address_range,other=EXCLUDED.other";
 
   # 初始化变量
   my $params;
 
   # 遍历解析到的地址对象
-  for my $addr ( values $self->{parser}{elements}{address}->%* ) {
+  for my $addr (values $self->{parser}{elements}{address}->%*) {
 
     # 构造 SQL VALUES
     my @addr;
@@ -591,7 +580,7 @@ sub saveAddress {
 
     # address_range
     my @address_range;
-    for ( my $i = 0; $i < $addr->range->mins->@*; $i++ ) {
+    for (my $i = 0; $i < $addr->range->mins->@*; $i++) {
       push @address_range, "[" . $addr->range->mins->[$i] . "," . $addr->range->maxs->[$i] . "]";
     }
     push @addr, \@address_range;
@@ -604,7 +593,7 @@ sub saveAddress {
   }
 
   # 遍历地址组对象
-  for my $addrG ( values $self->{parser}{elements}{addressGroup}->%* ) {
+  for my $addrG (values $self->{parser}{elements}{addressGroup}->%*) {
 
     # 构造 SQL VALUES
     my @addr;
@@ -626,7 +615,7 @@ sub saveAddress {
 
     # address_range
     my @address_range;
-    for ( my $i = 0; $i < $addrG->range->mins->@*; $i++ ) {
+    for (my $i = 0; $i < $addrG->range->mins->@*; $i++) {
       push @address_range, "[" . $addrG->range->mins->[$i] . "," . $addrG->range->maxs->[$i] . "]";
     }
     push @addr, \@address_range;
@@ -637,14 +626,14 @@ sub saveAddress {
     # 将数据压入 $params
     push $params->@*, \@addr;
   }
-  $self->batchExecute( $params, $sql );
+  $self->batchExecute($params, $sql);
 }
 
 #------------------------------------------------------------------------------
 # updateNetwork 抽象批量更新大网、私网接口
 #------------------------------------------------------------------------------
 sub updateNetwork {
-  my ( $self, $zones, @tables ) = @_;
+  my ($self, $zones, @tables) = @_;
 
   # 如果传入的非哈希引用则自动修正
   confess "网络区域必须是哈希引用"  if not ref $zones eq 'HASH' || not defined $zones;
@@ -663,10 +652,10 @@ sub updateNetwork {
     my $params;
 
     # 插入数据之前删除历史数据
-    $self->delete( where => {fw_id => $self->fwId}, table => $table );
+    $self->delete(where => {fw_id => $self->fwId}, table => $table);
 
     # 遍历防火墙网络区域
-    foreach my $zone ( keys $zones->%* ) {
+    foreach my $zone (keys $zones->%*) {
 
       # 这里的变量基于 Set 顺序一致
       my $addrIprange = $zones->{$zone}->addrIpRange;
@@ -679,7 +668,7 @@ sub updateNetwork {
       my $copy_maxs        = dclone $maxs;
 
       # 遍历 addrIprange 数组
-      while ( $copy_addrIprange->@* ) {
+      while ($copy_addrIprange->@*) {
 
         # 初始化变量 @zone
         my @zone;
@@ -705,7 +694,7 @@ sub updateNetwork {
     }
 
     # 插入快照数据
-    $self->batchExecute( $params, $sql );
+    $self->batchExecute($params, $sql);
   }
 }
 
@@ -723,7 +712,7 @@ sub updateStaticNatToNetwork {
   my $sql = "insert into $table (fw_id,zone,addr_range,addr_min,addr_max) values(?,?,?,?,?)";
 
   # 查询防火墙快照中的静态地址转换
-  for my $staticNat ( values $self->{parser}{elements}{staticNat}->%* ) {
+  for my $staticNat (values $self->{parser}{elements}{staticNat}->%*) {
 
     # 这里的变量基于 Set 顺序一致
     my $mins = $staticNat->natIpRange->mins;
@@ -734,7 +723,7 @@ sub updateStaticNatToNetwork {
     my $copy_maxs = dclone $maxs;
 
     # 遍历 $mins 数组
-    while ( $copy_mins->@* ) {
+    while ($copy_mins->@*) {
 
       # 初始化变量 @network
       my @network;
@@ -764,7 +753,7 @@ sub updateStaticNatToNetwork {
       # 将数据压入 params
       push $params->@*, \@network;
     }
-    $self->batchExecute( $params, $sql );
+    $self->batchExecute($params, $sql);
   }
 }
 
@@ -782,35 +771,35 @@ sub saveFwNetworkPrivate {
   my $fwInfo = $self->dbi->execute($select)->one;
 
   # 如果更新模式为手动更新则不做处理 | networkupdatemode = 2 代表手工
-  if ( $fwInfo->{networkupdatemode} == 2 ) {
+  if ($fwInfo->{networkupdatemode} == 2) {
     return;
   }
 
   # 非 NAT 防火墙，只需要维护大网信息
-  if ( $fwInfo->{is_nat} == 0 ) {
+  if ($fwInfo->{is_nat} == 0) {
 
     # 调用批量更新的抽象接口
     eval {
       my $zones = $self->{parser}{elements}{zone};
-      $self->updateNetwork( $zones, 'fw_network_main' );
+      $self->updateNetwork($zones, 'fw_network_main');
     };
 
     # confess "批量更新防火墙大网、私网期间捕捉异常：$@" if defined $@;
   }
 
   # 防火墙支持 NAT
-  if ( $fwInfo->{is_nat} > 0 ) {
+  if ($fwInfo->{is_nat} > 0) {
     my $sql      = "select * from fw_zone_state where fw_id = $fw_id";
     my $zoneInfo = $self->dbi->execute($sql)->all;
 
     # 遍历防火墙相关网络区域
-    my ( @protected, @unProtected, @unUse );
-    for my $zone ( $zoneInfo->@* ) {
-      if ( defined $zone->{is_protected_zone} ) {
-        if ( $zone->{is_protected_zone} == 1 ) {
+    my (@protected, @unProtected, @unUse);
+    for my $zone ($zoneInfo->@*) {
+      if (defined $zone->{is_protected_zone}) {
+        if ($zone->{is_protected_zone} == 1) {
           push @protected, $zone->{zone};
         }
-        elsif ( $zone->{is_protected_zone} == 0 ) {
+        elsif ($zone->{is_protected_zone} == 0) {
           push @unProtected, $zone->{zone};
         }
       }
@@ -820,12 +809,12 @@ sub saveFwNetworkPrivate {
     }
 
     # 没有定义包含和非保护的网络区域
-    if ( @protected == 0 && @unProtected == 0 ) {
+    if (@protected == 0 && @unProtected == 0) {
 
       # 向大网、私网表插入数据
       eval {
         my $zones = $self->{parser}{elements}{zone};
-        $self->updateNetwork( $zones, 'fw_network_private', 'fw_network_main' );
+        $self->updateNetwork($zones, 'fw_network_private', 'fw_network_main');
       };
 
       # confess "批量更新防火墙大网、私网期间捕捉异常：$@" if defined $@;
@@ -840,11 +829,11 @@ sub saveFwNetworkPrivate {
       map { $unprotectedZone->{$_} = $zoneIndex->{$_} } grep { exists $zoneIndex->{$_} } @unProtected;
 
       # 定义本地数据字典
-      my %tables = ( fw_network_private => $protectedZone, fw_network_main => $unprotectedZone );
+      my %tables = (fw_network_private => $protectedZone, fw_network_main => $unprotectedZone);
 
       # 向大网、私网表插入数据
-      foreach my $table ( keys %tables ) {
-        $self->updateNetwork( $tables{$table}, $table );
+      foreach my $table (keys %tables) {
+        $self->updateNetwork($tables{$table}, $table);
       }
     }
 
@@ -870,13 +859,13 @@ sub getFwName {
 
   # 查询 fw_info 下防火墙名，只返回一条结果
   my $tableName = 'fw_info';
-  my $raw       = $self->select( column => ['fw_name'], table => $tableName, where => {fw_id => $self->fwId} )->one;
+  my $raw       = $self->select(column => ['fw_name'], table => $tableName, where => {fw_id => $self->fwId})->one;
 
   # 检查是否成功返回查询结果
-  if ( not defined $raw ) {
+  if (not defined $raw) {
     confess "ERROR: 表 $tableName 中没有 fw_id 为 $self->fwId 的行";
   }
-  elsif ( not defined $raw->{FW_NAME} ) {
+  elsif (not defined $raw->{FW_NAME}) {
     confess "ERROR: 表 $tableName 中 fw_id 为 $self->fwId 的行 的字段 FW_NAME 的值为空";
   }
 
@@ -893,13 +882,13 @@ sub lock {
   # 锁定防火墙 fw_conf 表状态
   my $fwName    = $self->getFwName();
   my $tableName = 'fw_conf';
-  my $isLocking = $self->select( column => ['is_parsing'], table => $tableName, where => {fw_id => $self->fwId} )->one;
+  my $isLocking = $self->select(column => ['is_parsing'], table => $tableName, where => {fw_id => $self->fwId})->one;
 
   # 检查是否成功返回查询结果
-  if ( not defined $isLocking ) {
+  if (not defined $isLocking) {
     confess "ERROR: 设备 $self->fwId $fwName 在 表 $tableName 中的 is_parsing 字段不存在";
   }
-  elsif ( $isLocking->{is_parsing} == 0 ) {
+  elsif ($isLocking->{is_parsing} == 0) {
     $self->execute(
       "UPDATE $tableName SET is_parsing = 1, parse_start_time = :parse_start_time WHERE fw_id = :fw_id",
       {parse_start_time => Firewall::Utils::Date->new->getLocalDate, fw_id => $self->fwId}
@@ -910,13 +899,13 @@ sub lock {
   }
 
   # 查询 fw_conf 表状态
-  my $result = $self->select( column => ['is_parsing'], table => $tableName, where => {fw_id => $self->fwId} )->one;
+  my $result = $self->select(column => ['is_parsing'], table => $tableName, where => {fw_id => $self->fwId})->one;
 
   # 检查是否成功返回查询结果
-  if ( not defined $result ) {
+  if (not defined $result) {
     confess "ERROR: 表 $tableName 中 没有 fw_id 为  $self->fwId 的行，加锁失败";
   }
-  elsif ( $result->{is_parsing} != 1 ) {
+  elsif ($result->{is_parsing} != 1) {
     confess "ERROR: 表 $tableName 中 fw_id 为 $self->fwId 的行 的字段 is_parsing 的值未能更新为 1，加锁失败";
   }
 }
