@@ -28,7 +28,7 @@ has preDefinedService => (
   writer  => 'setPreDefinedService',
 );
 
-has preDefinedServiceTableName => ( is => 'ro', isa => 'Str', builder => '_buildPreDefinedServiceTableName', );
+has preDefinedServiceTableName => (is => 'ro', isa => 'Str', builder => '_buildPreDefinedServiceTableName',);
 
 #------------------------------------------------------------------------------
 # 明确继承 Dao::PredefinedService::Role 对象需要实现的方法
@@ -40,21 +40,16 @@ requires 'vendor';
 # 具体实现 createService 方法
 #------------------------------------------------------------------------------
 sub createService {
-  my ( $self, $param ) = @_;
-  my ( $fwId, $srvName, $protocol, $srcPort, $dstPort ) = @{$param}{qw/fwId srvName protocol srcPort dstPort/};
+  my ($self, $param) = @_;
+  my ($fwId, $srvName, $protocol, $srcPort, $dstPort) = @{$param}{qw/fwId srvName protocol srcPort dstPort/};
 
   # 实例化服务端口对象
   my $vendor       = $self->vendor;
   my $vendorPlugin = 'Firewall::Config::Element::Service::' . $vendor;
   eval("use $vendorPlugin");
   confess "Error Can not load plugin $vendorPlugin" if $@;
-  my $service = $vendorPlugin->new(
-    fwId     => $fwId,
-    srvName  => $srvName,
-    protocol => lc $protocol,
-    srcPort  => $srcPort,
-    dstPort  => $dstPort
-  );
+  my $service
+    = $vendorPlugin->new(fwId => $fwId, srvName => $srvName, protocol => lc $protocol, srcPort => $srcPort, dstPort => $dstPort);
 
   # 返回计算结果
   return $service;
@@ -64,18 +59,17 @@ sub createService {
 # 加载 Dao::PredefinedService::Role 预定义服务端口
 #------------------------------------------------------------------------------
 sub load {
-  my ( $self, $fwId ) = @_;
+  my ($self, $fwId) = @_;
 
   # 入参检查 $fwId
   confess "ERROR: 必须传递具体的 fwId" if not defined $fwId;
 
   # 查询预定义端口表
   my $preDefinedService;
-  my $services
-    = $self->dbi->select( [qw/srv_name protocol src_port dst_port/], table => $self->preDefinedServiceTableName )->all;
+  my $services = $self->dbi->select([qw/srv_name protocol src_port dst_port/], table => $self->preDefinedServiceTableName)->all;
 
   # 遍历预定义服务端口查询结果
-  for my $item ( @{$services} ) {
+  for my $item (@{$services}) {
 
     # 构造$param数据结构
     my $param = {fwId => $fwId};
@@ -87,7 +81,7 @@ sub load {
     my $service = $self->createService($param);
 
     # 抓取预定义的服务端口信息
-    if ( exists $preDefinedService->{$service->sign} ) {
+    if (exists $preDefinedService->{$service->sign}) {
       $preDefinedService->{$service->sign}->addMeta($service);
     }
     else {
